OutputCache

Struct OutputCache 

pub struct OutputCache { /* private fields */ }
A cache of outputs from the blockchain database.

Implementations

Source

impl OutputCache

pub const fn new( cached_outputs: IndexMap<u64, IndexMap<u64, OutputOnChain>>, number_of_outputs: IndexMap<u64, u64>, wanted_outputs: IndexMap<u64, IndexSet<u64>>, ) -> Self

Create a new OutputCache.

pub const fn cached_outputs( &self, ) -> &IndexMap<u64, IndexMap<u64, OutputOnChain>>

Returns the set of currently cached outputs.

Warning

Self::get_output should be preferred over this when possible, this will not contain all outputs asked for necessarily.

pub fn number_outs_with_amount(&self, amount: u64) -> usize

Returns the number of outputs in the blockchain with the given amount.

Warning

The cache will only track the amount of outputs with a given amount for the requested outputs. So if you do not request an output with amount when generating the cache the amount of outputs with value amount will not be tracked.

pub fn get_output(&self, amount: u64, index: u64) -> Option<&OutputOnChain>

Request an output with a given amount and amount index from the cache.

pub fn add_block_to_cache(&mut self, block: &VerifiedBlockInformation)

Adds a block to the cache.

This function will add any outputs to the cache that were requested when building the cache but were not in the DB, if they are in the block.

You should not add blocks to the cache before the block has been verified.